@@ -1,4 +1,5 @@
 use bevy::prelude::*;
+use notation_bevy_utils::prelude::SingleData;
 use std::sync::Arc;
 
 use notation_model::prelude::*;
@@ -8,7 +9,7 @@ use crate::prelude::EntryPlaying;
 #[derive(Bundle)]
 pub struct EntryBundle {
     pub name: Name,
-    pub entry: Arc<LaneEntry>,
+    pub entry: SingleData<LaneEntry>,
     pub playing: EntryPlaying,
 }
 
@@ -17,7 +18,7 @@ impl From<Arc<LaneEntry>> for EntryBundle {
         let playing = EntryPlaying::new(&v, PlayingState::Idle);
         EntryBundle {
             name: v.to_string().as_str().into(),
-            entry: v,
+            entry: SingleData::<LaneEntry>(v.as_ref().clone()),
             playing,
         }
     }
